==> jdcp-worker-0.3.1-sources.jar: ca/eandb/jdcp/worker/policy/osx/OSXCourtesyMonitorFactory.java <==
/*
 * Copyright (c) 2008 Bradley W. Kimmel
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package ca.eandb.jdcp.worker.policy.osx;

import ca.eandb.jdcp.worker.policy.PowerCourtesyMonitor;
import ca.eandb.jdcp.worker.policy.StandardCourtesyMonitorFactory;

/**
 * A <code>CourtesyMonitorFactory</code> for Mac OS X.
 * @author Brad Kimmel
 */
public final class OSXCourtesyMonitorFactory extends
    StandardCourtesyMonitorFactory {

  /* (non-Javadoc)
   * @see ca.eandb.jdcp.worker.policy.StandardCourtesyMonitorFactory#createPowerCourtesyMonitor()
   */
  public PowerCourtesyMonitor createPowerCourtesyMonitor() {
    // TODO Implement OSXPowerCourtesyMonitor and uncomment the following
    // line.
    //return new OSXPowerCourtesyMonitor();

    return null;
  }

}

==> jdcp-worker-0.4.2-sources.jar: ca/eandb/jdcp/worker/policy/osx/OSXCourtesyMonitorFactory.java <==
/*
 * Copyright (c) 2008 Bradley W. Kimmel
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package ca.eandb.jdcp.worker.policy.osx;

import ca.eandb.jdcp.worker.policy.PowerCourtesyMonitor;
import ca.eandb.jdcp.worker.policy.StandardCourtesyMonitorFactory;

/**
 * A <code>CourtesyMonitorFactory</code> for Mac OS X.
 * @author Brad Kimmel
 */
public final class OSXCourtesyMonitorFactory extends
    StandardCourtesyMonitorFactory {

  @Override
  public PowerCourtesyMonitor createPowerCourtesyMonitor() {
    // TODO Implement OSXPowerCourtesyMonitor and uncomment the following
    // line.
    //return new OSXPowerCourtesyMonitor();

    return null;
  }

}
